@@ -20,6 +20,10 @@ STATUS_CHOICES = [
     ('Archived', 'Archived'),
 ]
 
+circle_fields = ["@id", "name", "subtitle", "description", "creationDate", "status", "owner", "jabberID", "jabberRoom", "members"]
+if 'djangoldp_community' in settings.DJANGOLDP_PACKAGES:
+    circle_fields += ['community']
+
 
 class Circle(Model):
     name = models.CharField(max_length=255, blank=True, null=True, default='')
@@ -40,6 +44,7 @@ class Circle(Model):
         anonymous_perms = []
         authenticated_perms = []
         owner_perms = []
+        serializer_fields = circle_fields
         rdf_type = 'hd:circle'
 
     def __str__(self):
