@@ -5,7 +5,7 @@ from rest_framework.test import APITestCase, APIClient
 from guardian.shortcuts import assign_perm
 
 from djangoldp_circle.models import Circle, CircleMember, manage_deleted_owner
-from djangoldp_circle.tests.models import User
+from djangoldp_circle.tests.utils import get_random_user
 
 
 class PostTestCase(APITestCase):
@@ -13,15 +13,9 @@ class PostTestCase(APITestCase):
         self.client = APIClient()
 
     def setUpLoggedInUser(self):
-        self.user = User(email='test@mactest.co.uk', first_name='Test', last_name='Mactest', username='test',
-                         password='glass onion')
-        self.user.save()
+        self.user = get_random_user()
         self.client.force_authenticate(user=self.user)
 
-    def _get_random_user(self):
-        return User.objects.create(email='{}@test.co.uk'.format(str(uuid.uuid4())), first_name='Test', last_name='Test',
-                                   username=str(uuid.uuid4()))
-
     def test_post_circle(self):
         self.setUpLoggedInUser()
 
